LinchPin Command Line Shell implementation
==========================================

The linchpin.shell module contains calls to implement the Command Line
Interface within linchpin. It uses the `Click <http://click.pocoo.org>`_
command line interface composer. All calls here interface with the
:doc:`libcli` API.

.. automodule:: linchpin.shell
    :members:
    :undoc-members:
    :exclude-members: main,help,_handle_results,runcli

.. automodule:: linchpin.shell.click_default_group
    :members:
    :undoc-members:

